import React, { useMemo } from 'react';
import { Tooltip, Tabs } from 'antd';
import Filedetail from "@/components/Filedetail";
import DetailPro from '@/components/DetailPro';
import AutoTable from '@/components/AutoTable/mtable';
import { useNavigate } from '@umijs/max';
const fields = [
    {
        title: '合同单号',
        dataIndex: 'contractNo',
        key: 'contractNo'
    },
    {
        title: '合同金额（元）',
        dataIndex: 'amount',
        key: 'amount'
    },
    {
        title: '客户编号',
        dataIndex: 'customerNo',
        key: 'customerNo'
    },
    {
        title: '客户名称',
        dataIndex: 'customerName',
        key: 'customerName'
    },
    {
        title: '合同租期（月）',
        dataIndex: 'tenancy',
        key: 'tenancy'
    },
    {
        title: '营销区域',
        dataIndex: 'marketRegion',
        key: 'marketRegion'
    },
    {
        title: '智享店',
        dataIndex: 'zxstore',
        key: 'zxstore'
    },
    {
        title: '承接合同编号',
        dataIndex: 'undertakingNo',
        key: 'undertakingId'
    },
    {
        title: '合同负责人',
        dataIndex: 'head',
        key: 'head'
    },
    {
        title: '登记日期',
        dataIndex: 'registrationDate',
        key: 'registrationDate'
    },
    {
        title: '状态',
        dataIndex: 'statusName',
        key: 'statusName'
    },
    {
        title: '',
        valueType: 'split'
    },
    {
        title: '合同起租日',
        dataIndex: 'startLeaseDate',
        key: 'startLeaseDateList'
    },
    {
        title: '合同终止日',
        dataIndex: 'endLeaseDate',
        key: 'endLeaseDate'
    },
    {
        title: '回款设置（自然日）',
        dataIndex: 'collectionSet',
        key: 'collectionSet'
    },
    {
        title: '预警设置（自然日）',
        dataIndex: 'warnSet',
        key: 'warnSet'
    },
    {
        title: '',
        valueType: 'split'
    },
    {
        title: '去程运费（元）',
        dataIndex: 'tripFreight',
        key: 'tripFreight'
    },
    {
        title: '去程运费承担方',
        dataIndex: 'tripBearName',
        key: 'tripBearName'
    },
    {
        title: '返程运费（元）',
        dataIndex: 'returnFreight',
        key: 'returnFreight'
    },
    {
        title: '返程运费承担方',
        dataIndex: 'returnBearName',
        key: 'returnBearName'
    },
    {
        title: '',
        valueType: 'split'
    },
    {
        title: '退还押金（元）',
        dataIndex: 'refund',
        key: 'refund'
    },
    {
        title: '处理人',
        dataIndex: 'handleUserName',
        key: 'handleUserName'
    },
    {
        title: '处理时间',
        dataIndex: 'handleTime',
        key: 'handleTime'
    },
    {
        title: '相关文件',
        valueType: 'split'
    },
    {
        title: '合同文件',
        dataIndex: 'contractFileList',
        key: 'contractFileList',
        span: 3,
        render: (_, row) => {
            return <Filedetail files={row?.['contractFileList']} />
        }
    },
    {
        title: '起租单文件',
        dataIndex: 'startLeaseFileList',
        key: 'startLeaseFileList',
        render: (_, row) => {
            return <Filedetail files={row?.['startLeaseFileList']} />
        }
    },
    {
        title: '发运单上传',
        dataIndex: 'hairuseFileList',
        key: 'hairuseFileList',
        render: (_, row) => {
            return <Filedetail files={row?.['hairuseFileList']} />
        }
    },
    {
        title: '租赁物交付确认单上传',
        dataIndex: 'leaseDeliverFileList',
        key: 'leaseDeliverFileList',
        render: (_, row) => {
            return <Filedetail files={row?.['leaseDeliverFileList']} />
        }
    },
    {
        title: '租赁物归还确认单文件',
        dataIndex: 'leaseReturnFileList',
        key: 'leaseReturnFileList',
        render: (_, row) => {
            return <Filedetail files={row?.['leaseReturnFileList']} />
        }
    },
    {
        title: '押金归还确认单文件',
        dataIndex: 'refundFileList',
        key: 'refundFileList',
        render: (_, row) => {
            return <Filedetail files={row?.['refundFileList']} />
        }
    },
];
const Details = ({ drawer }) => {
    const navigator = useNavigate();
    const columns = [
        {
            title: '设备编号',
            dataIndex: 'equipmentNo',
            key: 'equipmentNo',
            render: (_, row) => {
                return (
                    <Tooltip title={row.equipmentNo}>
                        {
                            row.pageStatus == 0 ?
                                <span className="table-cell">
                                    {row.equipmentNo}
                                </span>
                                :
                                <a
                                    className="table-cell"
                                    onClick={() => {
                                        navigator('/lease/costanalysis', {
                                            state: {
                                                pageStatus: row.pageStatus,
                                                extraparams: {
                                                    contractId: row.contractId,
                                                    equipmentId: row.equipmentId
                                                }
                                            }
                                        })
                                    }}
                                >
                                    {row.equipmentNo}
                                </a>
                        }

                    </Tooltip>
                );
            }
        },
        {
            title: '设备名称',
            dataIndex: 'equipmentName',
            key: 'equipmentName',
        },
        {
            title: '莫格云眼',
            dataIndex: 'intelligentUnitNo',
            key: 'intelligentUnitNo',
        },
        {
            title: '每期单价（元）',
            dataIndex: 'unitPrice',
            key: 'unitPrice',
            hideInSearch: true
        },
        {
            title: '智享价（元）',
            dataIndex: 'zxPrice',
            key: 'zxPrice',
            hideInSearch: true
        },
        {
            title: '返利金额（元）',
            dataIndex: 'rebatePrice',
            key: 'rebatePrice',
            hideInSearch: true
        },
        {
            title: '押金（元）',
            dataIndex: 'deposit',
            key: 'deposit',
            hideInSearch: true
        },
        {
            title: '实际结束时间',
            dataIndex: 'realEndDate',
            key: 'realEndDate',
            hideInSearch: true
        },
        {
            title: '违约金（元）',
            dataIndex: 'violatePrice',
            key: 'violatePrice',
            hideInSearch: true
        },
    ];
    const items = useMemo(() => {
        return [
            {
                key: '1',
                label: '基本信息',
                children: <DetailPro
                    fields={fields}
                    detailpath="/lease/umContract/queryDetail"
                    params={{ id: drawer?.item?.id }}
                />,
            },
            {
                key: '2',
                label: '合同详情',
                children: <AutoTable
                    columns={columns}
                    path={'/lease/umContractEquipment/queryByContractId'}
                    resizeable={false}
                    pageextra="none"
                    bordered={false}
                    extraparams={{ contractId: drawer?.item?.id }}
                    pagination={'false'}
                />,
            }
        ]
    }, [drawer?.item?.id])
    return <div>
        <Tabs items={items} destroyInactiveTabPane />
    </div>
}
export default Details;